=============================
DIALS Regression Data Manager
=============================

.. image:: https://img.shields.io/pypi/v/dials_data.svg
        :target: https://pypi.python.org/pypi/dials_data
        :alt: PyPI release

.. image:: https://img.shields.io/conda/vn/conda-forge/dials-data.svg
        :target: https://anaconda.org/conda-forge/dials-data
        :alt: Conda release

.. image:: https://travis-ci.com/dials/data.svg?branch=master
        :target: https://travis-ci.com/dials/data
        :alt: Build status

.. image:: https://img.shields.io/lgtm/grade/python/g/dials/data.svg?logo=lgtm&logoWidth=18
        :target: https://lgtm.com/projects/g/dials/data/context:python
        :alt: Language grade: Python

.. image:: https://img.shields.io/lgtm/alerts/g/dials/data.svg?logo=lgtm&logoWidth=18
        :target: https://lgtm.com/projects/g/dials/data/alerts/
        :alt: Total alerts

.. image:: https://readthedocs.org/projects/dials-data/badge/?version=latest
        :target: https://dials-data.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation status

.. image:: https://img.shields.io/pypi/pyversions/dials_data.svg
        :target: https://pypi.org/project/dials_data/
        :alt: Supported Python versions

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
        :target: https://github.com/ambv/black
        :alt: Code style: black

.. image:: https://img.shields.io/pypi/l/dials_data.svg
        :target: https://pypi.python.org/pypi/dials_data
        :alt: BSD license

A python package providing data files used for regression tests in
DIALS_, dxtbx_, xia2_ and related packages.

If you want to know more about what ``dials_data`` is you can
have a read through the `background information <https://dials-data.readthedocs.io/en/latest/why.html>`__.

For everything else `the main documentation <https://dials-data.readthedocs.io/>`__ is probably the best start.


Installation
^^^^^^^^^^^^

To install this package in a normal Python environment, run::

    pip install dials_data

and then you can use it with::

    dials.data

If you are in a conda environment you can instead run::

    conda install -c conda-forge dials_data

For more details please take a look at the
`installation and usage page <https://dials-data.readthedocs.io/en/latest/installation.html>`__.


.. _DIALS: https://dials.github.io
.. _dxtbx: https://github.com/cctbx/cctbx_project/tree/master/dxtbx
.. _xia2: https://xia2.github.io
